<!DOCTYPE TS><TS>
<defaultcodec></defaultcodec>
<context>
    <name>AdvSearch</name>
    <message>
        <source>Cannot execute pure negative query. Please enter common terms in the &apos;any words&apos; field</source>
        <translation>Ausschließlich negative Suche nicht möglich. Bitte geben Sie mindestens einen positiven Suchbegriff an.</translation>
    </message>
    <message>
        <source>All clauses</source>
        <translation>Alle Ausdrücke</translation>
    </message>
    <message>
        <source>Any clause</source>
        <translation>Einen der Ausdrücke</translation>
    </message>
    <message>
        <source>texts</source>
        <translation>Texte</translation>
    </message>
    <message>
        <source>spreadsheets</source>
        <translation>Tabellen</translation>
    </message>
    <message>
        <source>presentations</source>
        <translation>Präsentationen</translation>
    </message>
    <message>
        <source>media</source>
        <translation>Medien</translation>
    </message>
    <message>
        <source>messages</source>
        <translation>Nachrichten</translation>
    </message>
    <message>
        <source>other</source>
        <translation>andere</translation>
    </message>
</context>
<context>
    <name>AdvSearchBase</name>
    <message>
        <source>Advanced search</source>
        <translation>Erweiterte Suche</translation>
    </message>
    <message>
        <source>Search for files&lt;br&gt;having all of:</source>
        <translation type="obsolete">Rechercher les fichiers&lt;br&gt;vérifiant:</translation>
    </message>
    <message>
        <source>All non blank fields will be combined with AND conjunctions. &lt;br&gt;All fields except &quot;exact phrase&quot; can accept a mix of simple words, and phrases enclosed in double quotes.</source>
        <translation type="obsolete">Tous les champs renseignés seront combinées avec des &quot;ET&quot;.&lt;br&gt;Tous les champs sauf &quot;phrase&quot; peuvent accepter un mélange de mots et de phrases entourées d&apos;apostrophes doubles. </translation>
    </message>
    <message>
        <source>All of these</source>
        <translation type="obsolete">Tous ces mots</translation>
    </message>
    <message>
        <source>Enter words, and/or quoted phrases.</source>
        <translation type="obsolete">Entrer des mots, et/ou des phrases entre doubles apostrophes.</translation>
    </message>
    <message>
        <source>This exact phrase</source>
        <translation type="obsolete">Cette phrase exactement</translation>
    </message>
    <message>
        <source>Enter words.</source>
        <translation type="obsolete">Entrer des mots.</translation>
    </message>
    <message>
        <source>Any of these</source>
        <translation type="obsolete">Un de ces mots</translation>
    </message>
    <message>
        <source>None of these</source>
        <translation type="obsolete">Aucun de ces mots</translation>
    </message>
    <message>
        <source>File name matching</source>
        <translation type="obsolete">Modèle de nom de fichier</translation>
    </message>
    <message>
        <source>Enter file name. * and ? are wildcards.</source>
        <translation type="obsolete">Entrer un nom de fichier. * et ? peuvent être utilisés comme jokers.</translation>
    </message>
    <message>
        <source>Restrict file types</source>
        <translation>Einschränkung der Dateitypen</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation>Als Standard speichern</translation>
    </message>
    <message>
        <source>Searched file types</source>
        <translation>Durchsuchte Dateitypen</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation>Alle ----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation>Auswahl -----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation>&lt;----- Auswahl</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation>&lt;----- Alle</translation>
    </message>
    <message>
        <source>Ignored file types</source>
        <translation>Ignorierte Dateitypen</translation>
    </message>
    <message>
        <source>Enter top directory for search</source>
        <translation>Geben Sie das Basisverzeichnis für die Suche an</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Durchsuchen</translation>
    </message>
    <message>
        <source>Restrict results to files in subtree:</source>
        <translation>Einschränkung der Ergebnisse auf Dateien in folgendem Unterverzeichnis:</translation>
    </message>
    <message>
        <source>Start Search</source>
        <translation>Suche starten</translation>
    </message>
    <message>
        <source>Dismiss</source>
        <translation type="obsolete">Annuler</translation>
    </message>
    <message>
        <source>Search for &lt;br&gt;documents&lt;br&gt;satisfying:</source>
        <translation>Suche nach Dokumenten, die folgende Kriterien erfüllen:</translation>
    </message>
    <message>
        <source>All non blank fields will be combined with OR or AND conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
        <translation type="obsolete">Alle angegebenen Felder werden mit ODER oder UND Bedingungen verknüpft. &lt;br&gt;In Felder der Typen &quot;Irgendein&quot;, &quot;Alle&quot; und &quot;Kein&quot; können mehrere Einzelwörter und Sätze, die durch Anführungszeichen eingeschlossen werden, eingegeben werden.&lt;br&gt; Leere Felder werden ignoriert. </translation>
    </message>
    <message>
        <source>Delete clause</source>
        <translation>letzten Ausdruck löschen</translation>
    </message>
    <message>
        <source>Add clause</source>
        <translation>Neuen Ausdruck zufügen</translation>
    </message>
    <message>
        <source>Check this to enable filtering on file types</source>
        <translation>Auswählen, um Filterung auf Dateitypen zu aktivieren</translation>
    </message>
    <message>
        <source>By categories</source>
        <translation>Per Kategorien</translation>
    </message>
    <message>
        <source>Check this to use file categories instead of raw mime types</source>
        <translation>Auswählen, um Dateikategorien anstatt der Mime-Typen zu verwenden</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>All non empty fields on the right will be combined with AND (&quot;All clauses&quot; choice) or OR (&quot;Any clause&quot; choice) conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Configuration problem: </source>
        <translation type="obsolete">Konfigurationsproblem:</translation>
    </message>
    <message>
        <source>No db directory in configuration</source>
        <translation>Kein Datenbankverzeichnis konfiguriert</translation>
    </message>
    <message>
        <source>Cannot create temporary directory</source>
        <translation type="obsolete">Impossible de créer le répertoire temporaire</translation>
    </message>
    <message>
        <source>Could not open database in </source>
        <translation>Fehler beim Öffnen der Datenbank in</translation>
    </message>
    <message>
        <source>.
Click Cancel if you want to edit the configuration file before indexation starts, or Ok to let it proceed.</source>
        <translation>.
Drücken Sie Abbrechen, um die Konfigurationsdatei vor dem Start der Indizierung anzupassen oder OK um mit der Indizierung zu beginnen.</translation>
    </message>
    <message>
        <source>Configuration problem (dynconf</source>
        <translation>Konfigurationsproblem (dynconf)</translation>
    </message>
</context>
<context>
    <name>Preview</name>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Previsualisation</translation>
    </message>
    <message>
        <source>Preview 1</source>
        <translation type="obsolete">Previsualisation 1</translation>
    </message>
    <message>
        <source>&amp;Search for:</source>
        <translation>&amp;Suche nache:</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Nächstes</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+S</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>&amp;Vorheriges</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation type="obsolete">Alt+P</translation>
    </message>
    <message>
        <source>Match &amp;Case</source>
        <translation type="unfinished">Groß/Kleinschreibung &amp;beachten</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+C</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Leeren</translation>
    </message>
    <message>
        <source>Can&apos;t turn doc into internal rep for </source>
        <translation type="obsolete">Impossible de créer une représentation interne pour </translation>
    </message>
    <message>
        <source>Creating preview text</source>
        <translation>Erzeuge Vorschautext</translation>
    </message>
    <message>
        <source>Loading preview text into editor</source>
        <translation>Lade Vorschautext in den Editor</translation>
    </message>
    <message>
        <source>Cannot create temporary directory</source>
        <translation>Fehler beim Anlegen des temporären Verzeichnisses</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Close Tab</source>
        <translation>Reiter schließen</translation>
    </message>
    <message>
        <source>File does not exist</source>
        <translation>Datei existiert nicht</translation>
    </message>
    <message>
        <source>Missing helper program: </source>
        <translation>Fehlendes Hilfsprogramm:</translation>
    </message>
    <message>
        <source>Can&apos;t turn doc into internal representation for </source>
        <translation>Fehler bei der Indizierung des Dokuments </translation>
    </message>
</context>
<context>
    <name>PreviewBase</name>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Vorschau</translation>
    </message>
    <message>
        <source>Preview 1</source>
        <translation type="obsolete">Vorschau 1</translation>
    </message>
    <message>
        <source>&amp;Search for:</source>
        <translation type="obsolete">&amp;Suchen nach:</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="obsolete">&amp;Nächstes</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+N</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation type="obsolete">&amp;Voriges</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation type="obsolete">Alt+V</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="obsolete">Löschen</translation>
    </message>
    <message>
        <source>Match &amp;Case</source>
        <translation type="obsolete">Groß/Kleinschreibung &amp;beachten</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+B</translation>
    </message>
</context>
<context>
    <name>PreviewTextEdit</name>
    <message>
        <source>Show fields</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show main text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Global parameters</source>
        <translation>Globale Parameter</translation>
    </message>
    <message>
        <source>Local parameters</source>
        <translation>Lokale Parameter</translation>
    </message>
    <message>
        <source>&lt;b&gt;Customised subtrees</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The list of subdirectories in the indexed hierarchy &lt;br&gt;where some parameters need to be redefined. Default: empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;i&gt;The parameters that follow are set either at the top level, if nothing&lt;br&gt;or an empty line is selected in the listbox above, or for the selected subdirectory.&lt;br&gt;You can add or remove directories by clicking the +/- buttons.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipped names</source>
        <translation>Übersprungene Namen</translation>
    </message>
    <message>
        <source>These are patterns for file or directory  names which should not be indexed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default character set</source>
        <translation>Standard Zeichensatz</translation>
    </message>
    <message>
        <source>This is the character set used for reading files which do not identify the character set internally, for example pure text files.&lt;br&gt;The default value is empty, and the value from the NLS environnement is used.</source>
        <translation>Der Zeichensatz der für Dateien benutzt wird, die ihren Zeichensatz nicht intern definieren, z.B. Textdateien.&lt;br&gt;Standardwert ist leer und der Wert der NLS Umgebung wird benutzt.</translation>
    </message>
    <message>
        <source>Follow symbolic links</source>
        <translation>Folge symbolischen Links</translation>
    </message>
    <message>
        <source>Follow symbolic links while indexing. The default is no, to avoid duplicate indexing</source>
        <translation>Folge symbolischen Links währen der Indizierung. Standard ist nein, um doppelte Indizierung zu vermeiden</translation>
    </message>
    <message>
        <source>Index all file names</source>
        <translation>Indiziere alle Dateinamen</translation>
    </message>
    <message>
        <source>Index the names of files for which the contents cannot be identified or processed (no or unsupported mime type). Default true</source>
        <translation>Indiziere alle Namen der Dateien, deren Inhalt nicht bestimmt oder bearbeitet werden kann (keiner oder nicht unterstützter mime Typ). Standard: ja</translation>
    </message>
</context>
<context>
    <name>QtGuiResListPager</name>
    <message>
        <source>Previous</source>
        <translation type="obsolete">Voriges</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="obsolete">Nächstes</translation>
    </message>
    <message>
        <source>(show query)</source>
        <translation type="obsolete">(Suche zeigen)</translation>
    </message>
</context>
<context>
    <name>RclMain</name>
    <message>
        <source>Advanced search</source>
        <translation type="obsolete">Recherche avancée</translation>
    </message>
    <message>
        <source>About Recoll</source>
        <translation>über Recoll</translation>
    </message>
    <message>
        <source>Indexing in progress</source>
        <translation type="obsolete">Indexation en cours</translation>
    </message>
    <message>
        <source>No external viewer configured for mime type </source>
        <translation>Kein externer Betrachter für Mime Type </translation>
    </message>
    <message>
        <source>Executing: [</source>
        <translation>Ausführen: [</translation>
    </message>
    <message>
        <source>Cannot retrieve document info from database</source>
        <translation>Keine Informationen zum Dokument in der Datenbank</translation>
    </message>
    <message>
        <source>Cannot access document file: </source>
        <translation>Fehler beim Zugriff auf das Dokument:</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Previsualisation</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>Can&apos;t create preview window</source>
        <translation>Fehler beim Erzeugen des Vorschaufensters</translation>
    </message>
    <message>
        <source>&lt;b&gt;Displaying results starting at index %1 (maximum set size %2)&lt;/b&gt;&lt;/p&gt;
</source>
        <translation type="obsolete">&lt;b&gt;Affichage des résultats à partir de l&apos;index %1 (nombre maximum %2)&lt;/b&gt;&lt;/p&gt;
</translation>
    </message>
    <message>
        <source>Sort criteria</source>
        <translation type="obsolete">Critères de tri</translation>
    </message>
    <message>
        <source>User interface preferences</source>
        <translation type="obsolete">Préférences pour l&apos;interface utilisateur</translation>
    </message>
    <message>
        <source>Query results</source>
        <translation>Ergebnisse</translation>
    </message>
    <message>
        <source>Query results (sorted)</source>
        <translation type="obsolete">Ergebnisse (sortiert)</translation>
    </message>
    <message>
        <source>Document history</source>
        <translation>Dokumenthistorie</translation>
    </message>
    <message>
        <source>Document history (sorted)</source>
        <translation type="obsolete">Historique des documents consultés (trié)</translation>
    </message>
    <message>
        <source>Query details</source>
        <translation type="obsolete">Détail de la recherche</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation type="obsolete">Document inaccessible</translation>
    </message>
    <message>
        <source>History data</source>
        <translation>Historische Daten</translation>
    </message>
    <message>
        <source>Starting help browser </source>
        <translation type="obsolete">Starte Hilfebrowser</translation>
    </message>
    <message>
        <source>Indexing in progress: </source>
        <translation>Indizierung in Arbeit:</translation>
    </message>
    <message>
        <source>Files</source>
        <translation>Dateien</translation>
    </message>
    <message>
        <source>Purge</source>
        <translation>säubern</translation>
    </message>
    <message>
        <source>Stemdb</source>
        <translation>Wortstämme</translation>
    </message>
    <message>
        <source>Closing</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>This search is not active any more</source>
        <translation>Diese Suche ist nicht mehr aktiv</translation>
    </message>
    <message>
        <source>Can&apos;t start query: </source>
        <translation>Kann die Suche nicht starten:</translation>
    </message>
    <message>
        <source>Spell expansion</source>
        <translation type="obsolete">Approximation orthographique</translation>
    </message>
    <message>
        <source>Bad viewer command line for %1: [%2]
Please check the mimeconf file</source>
        <translation>Fehlerhaftes Betrachterkommando für %1: [%2]
Überprüfen Sie die Datei mimeconf</translation>
    </message>
    <message>
        <source>The viewer specified in mimeconf for %1: %2 is not found.
Do you want to start the  preferences dialog ?</source>
        <translation>Der in der mimeconf konfigurierte Betrachter für %1: %2 wurde nicht gefunden.
Soll der Voreinstellungsdialog geöffnet werden?</translation>
    </message>
    <message>
        <source>Cannot extract document or create temporary file</source>
        <translation>Fehler beim Extrahieren des Dokuments oder beim Erzeugen der temporären datei</translation>
    </message>
    <message>
        <source>(no stemming)</source>
        <translation>(keine Wortstammerweiterung)</translation>
    </message>
    <message>
        <source>(all languages)</source>
        <translation>(alle Sprachen)</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>Fehler beim Holen der Wortstammsprachen</translation>
    </message>
    <message>
        <source>Update &amp;Index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indexing interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop &amp;Indexing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>media</source>
        <translation type="unfinished">Medien</translation>
    </message>
    <message>
        <source>message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>other</source>
        <translation type="unfinished">andere</translation>
    </message>
    <message>
        <source>presentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sorted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>filtered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>External applications/commands needed and not found for indexing your file types:

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No helpers found missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing helper programs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save file dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose a file name to save under</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RclMainBase</name>
    <message>
        <source>Search</source>
        <translation type="obsolete">Rechercher</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="obsolete">Effacer</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="obsolete">Ctrl+S</translation>
    </message>
    <message>
        <source>Previous page</source>
        <translation>vorige Seite</translation>
    </message>
    <message>
        <source>Next page</source>
        <translation>nächste Seite</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="obsolete">Beenden</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>Start Indexing</source>
        <translation type="obsolete">Commencer l&apos;indexation</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Werkzeuge</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>Erase search entry</source>
        <translation type="obsolete">Effacer l&apos;entrée</translation>
    </message>
    <message>
        <source>Start query</source>
        <translation type="obsolete">Démarrer la recherche</translation>
    </message>
    <message>
        <source>&amp;All terms</source>
        <translation type="obsolete">&amp;Tous </translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation type="obsolete">Alt+T</translation>
    </message>
    <message>
        <source>Do documents have to contain all terms in query?</source>
        <translation type="obsolete">Est-ce que tous les termes doivent se trouver dans chaque document ?</translation>
    </message>
    <message>
        <source>If this is set, each returned document will contain all the terms in the query. Else documents will be ordered by relevance, but may not contain all the terms.</source>
        <translation type="obsolete">Détermine si les documents doivent chacun contenir tous les termes, ou si ils seront simplement triés par pertinence, avec possibilité d&apos;absence de certains termes.</translation>
    </message>
    <message>
        <source>Enter search terms here</source>
        <translation type="obsolete">Entrer les termes à chercher</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Voreinstellungen</translation>
    </message>
    <message>
        <source>Search tools</source>
        <translation>Suchwerkzeuge</translation>
    </message>
    <message>
        <source>Result list</source>
        <translation>Ergebnisliste</translation>
    </message>
    <message>
        <source>Start &amp;Indexing</source>
        <translation type="obsolete">Démarrer l&apos;&amp;Indexation</translation>
    </message>
    <message>
        <source>&amp;About Recoll</source>
        <translation>&amp;über Recoll</translation>
    </message>
    <message>
        <source>Document &amp;History</source>
        <translation>&amp;Dokumentenhistorie</translation>
    </message>
    <message>
        <source>Document  History</source>
        <translation>Dokumentenhistorie</translation>
    </message>
    <message>
        <source>Advanced Search</source>
        <translation type="obsolete">Recherche avancée</translation>
    </message>
    <message>
        <source>&amp;Advanced Search</source>
        <translation>&amp;Erweiterte Suche</translation>
    </message>
    <message>
        <source>Advanced/complex  Search</source>
        <translation>Erweiterte/komplexe Suche</translation>
    </message>
    <message>
        <source>&amp;Sort parameters</source>
        <translation>&amp;Sortierparameter</translation>
    </message>
    <message>
        <source>Sort parameters</source>
        <translation>Sortierparameter</translation>
    </message>
    <message>
        <source>Next page of results</source>
        <translation>nächste Ergebnisseite</translation>
    </message>
    <message>
        <source>Previous page of results</source>
        <translation>vorige Ergebnisseite</translation>
    </message>
    <message>
        <source>&amp;Query configuration</source>
        <translation>&amp;Suchkonfiguration</translation>
    </message>
    <message>
        <source>User manual</source>
        <translation type="obsolete">Manuel</translation>
    </message>
    <message>
        <source>&amp;User manual</source>
        <translation>&amp;Benutzerhandbuch</translation>
    </message>
    <message>
        <source>Recoll</source>
        <translation>Recoll</translation>
    </message>
    <message>
        <source>About Recoll</source>
        <translation type="obsolete">À propos de Recoll</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Update index</source>
        <translation type="obsolete">MIse à jour index</translation>
    </message>
    <message>
        <source>Update &amp;index</source>
        <translation>&amp;Indizieren</translation>
    </message>
    <message>
        <source>Term &amp;explorer</source>
        <translation>&amp;Ausdruck Explorer</translation>
    </message>
    <message>
        <source>Term explorer tool</source>
        <translation>Ausdruck Explorer Werkzeug</translation>
    </message>
    <message>
        <source>External index dialog</source>
        <translation>Dialog für externe Indizierung</translation>
    </message>
    <message>
        <source>&amp;Erase document history</source>
        <translation>&amp;Lösche Dokumenthistorie</translation>
    </message>
    <message>
        <source>First page</source>
        <translation>Erste Seite</translation>
    </message>
    <message>
        <source>Go to first page of results</source>
        <translation>Gehe zu der ersten Seite der Ergebnisse</translation>
    </message>
    <message>
        <source>&amp;Indexing configuration</source>
        <translation>&amp;Indizierungskonfiguration</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Show missing helpers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RclResList</name>
    <message>
        <source>Result list</source>
        <translation type="obsolete">Liste de résultats</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation type="obsolete">Document inaccessible</translation>
    </message>
    <message>
        <source>Show query details</source>
        <translation type="obsolete">Afficher la requête</translation>
    </message>
    <message>
        <source>&lt;b&gt;Displaying results starting at index %1 (maximum set size %2)&lt;/b&gt;&lt;/p&gt;
</source>
        <translation type="obsolete">&lt;b&gt;Affichage des résultats à partir de l&apos;index %1 (nombre maximum %2)&lt;/b&gt;&lt;/p&gt;
</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="obsolete">&amp;Voir contenu</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="obsolete">&amp;Editer</translation>
    </message>
    <message>
        <source>&amp;Copy File Name</source>
        <translation type="obsolete">&amp;Copier le nom de fichier</translation>
    </message>
    <message>
        <source>Copy &amp;URL</source>
        <translation type="obsolete">Copier l&apos;&amp;Url</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
        <translation type="obsolete">&lt;p&gt;&lt;b&gt;Aucun résultat&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&amp;More like this</source>
        <translation type="obsolete">Documents &amp;ressemblants</translation>
    </message>
    <message>
        <source>Query details</source>
        <translation type="obsolete">Détail de la recherche</translation>
    </message>
</context>
<context>
    <name>ResList</name>
    <message>
        <source>Result list</source>
        <translation>Ergebnisse</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation type="unfinished">Dokument nicht verfügbar</translation>
    </message>
    <message>
        <source>Show query details</source>
        <translation type="obsolete">Anzeige der Suchdetails</translation>
    </message>
    <message>
        <source>&lt;b&gt;Displaying results starting at index %1 (maximum set size %2)&lt;/b&gt;&lt;/p&gt;
</source>
        <translation type="obsolete">&lt;b&gt;Affichage des résultats à partir de l&apos;index %1 (nombre maximum %2)&lt;/b&gt;&lt;/p&gt;
</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished">Voriges</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished">Nächstes</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
        <translation type="unfinished">&lt;p&gt;&lt;b&gt;keine Ergebnisse&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Vorschau</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editieren</translation>
    </message>
    <message>
        <source>&amp;Copy File Name</source>
        <translation type="obsolete">&amp;Copier le nom de fichier</translation>
    </message>
    <message>
        <source>Copy &amp;URL</source>
        <translation>&amp;Url kopieren</translation>
    </message>
    <message>
        <source>Find &amp;similar documents</source>
        <translation>&amp;Gleiche Dokumente finden</translation>
    </message>
    <message>
        <source>Query details</source>
        <translation>Suchdetails</translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; out of &lt;b&gt;%3&lt;/b&gt; for </source>
        <translation type="obsolete">Documents &lt;b&gt;%1-%2&lt;/b&gt; parmi &lt;b&gt;%3&lt;/b&gt; pour </translation>
    </message>
    <message>
        <source>(show query)</source>
        <translation>(Suche zeigen)</translation>
    </message>
    <message>
        <source>Copy &amp;File Name</source>
        <translation>&amp;Dateinamen kopieren</translation>
    </message>
    <message>
        <source>P&amp;arent document/folder</source>
        <translation>&amp;übergeordnetes Dokument/Ordner</translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; out of at least &lt;b&gt;%3&lt;/b&gt; for </source>
        <translation type="obsolete">Dokumente  &lt;b&gt;%1-%2&lt;b&gt; von mindestens &lt;b&gt;%3&lt;/b&gt; für </translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; for </source>
        <translation type="obsolete">Dokumente &lt;b&gt;%1-%2&lt;/b&gt; für </translation>
    </message>
    <message>
        <source>filtered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sorted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document history</source>
        <translation type="unfinished">Dokumenthistorie</translation>
    </message>
    <message>
        <source>Save to File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; out of at least &lt;b&gt;%d&lt;/b&gt; for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResListBase</name>
    <message>
        <source>Result list</source>
        <translation type="obsolete">Liste de résultats</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation type="obsolete">Document inaccessible</translation>
    </message>
    <message>
        <source>&lt;b&gt;Displaying results starting at index %1 (maximum set size %2)&lt;/b&gt;&lt;/p&gt;
</source>
        <translation type="obsolete">&lt;b&gt;Affichage des résultats à partir de l&apos;index %1 (nombre maximum %2)&lt;/b&gt;&lt;/p&gt;
</translation>
    </message>
</context>
<context>
    <name>SSearch</name>
    <message>
        <source>Any term</source>
        <translation>Irgendein Ausdruck</translation>
    </message>
    <message>
        <source>All terms</source>
        <translation>Alle Ausdrücke</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <source>Completions</source>
        <translation>Erweiterungen</translation>
    </message>
    <message>
        <source>Select an item:</source>
        <translation>Wählen Sie ein Element:</translation>
    </message>
    <message>
        <source>Too many completions</source>
        <translation>Zu viele Vervollständigungen:</translation>
    </message>
    <message>
        <source>Query language</source>
        <translation>Suchsprache</translation>
    </message>
    <message>
        <source>Bad query string</source>
        <translation>Fehlerhafter Suchstring</translation>
    </message>
    <message>
        <source>Out of memory</source>
        <translation>Kein freier Speicher mehr verfügbar</translation>
    </message>
</context>
<context>
    <name>SSearchBase</name>
    <message>
        <source>SSearchBase</source>
        <translation>SSearchBase</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Erase search entry</source>
        <translation>Sucheintrag löschen</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <source>Start query</source>
        <translation>Suche starten</translation>
    </message>
    <message>
        <source>&amp;All terms</source>
        <translation type="obsolete">&amp;Tous </translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation type="obsolete">Alt+T</translation>
    </message>
    <message>
        <source>Do documents have to contain all terms in query?</source>
        <translation type="obsolete">Est-ce que tous les termes doivent se trouver dans chaque document ?</translation>
    </message>
    <message>
        <source>If this is set, each returned document will contain all the terms in the query. Else documents will be ordered by relevance, but may not contain all the terms.</source>
        <translation type="obsolete">Détermine si les documents doivent chacun contenir tous les termes, ou si ils seront simplement triés par pertinence, avec possibilité d&apos;absence de certains termes.</translation>
    </message>
    <message>
        <source>Enter search terms here</source>
        <translation type="obsolete">Entrer les termes à chercher</translation>
    </message>
    <message>
        <source>Choose type of search: any term, all terms, filename with possible wildcards.</source>
        <translation type="obsolete">Wählen Sie die Art der Suche: irgendein Ausdruck, alle Ausdrücke, Dateiname (ggf. mit Wildcards)</translation>
    </message>
    <message>
        <source>Any term</source>
        <translation type="obsolete">Certains termes</translation>
    </message>
    <message>
        <source>All terms</source>
        <translation type="obsolete">Tous les termes</translation>
    </message>
    <message>
        <source>File name</source>
        <translation type="obsolete">Nom de fichier</translation>
    </message>
    <message>
        <source>Completions</source>
        <translation type="obsolete">Complétions</translation>
    </message>
    <message>
        <source>Select an item:</source>
        <translation type="obsolete">Sélectionner un élément:</translation>
    </message>
    <message>
        <source>Enter search terms here. CTRL-TAB for completions of current term.</source>
        <translation type="obsolete">Entrer les mots recherchés. CTRL-TAB pour obtenir une liste de terminaisons pour l&apos;entrée en cours.</translation>
    </message>
    <message>
        <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
        <translation>Suchausdruck hier eingeben. Drücken Sie ESC SPC für Vervollständigungen des aktuellen Ausdrucks</translation>
    </message>
    <message>
        <source>Choose search type.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchClauseW</name>
    <message>
        <source>SearchClauseW</source>
        <translation>SearchClauseW</translation>
    </message>
    <message>
        <source>Any of these</source>
        <translation>Irgendeins dieser</translation>
    </message>
    <message>
        <source>All of these</source>
        <translation>Alle diese</translation>
    </message>
    <message>
        <source>None of these</source>
        <translation>Keins dieser</translation>
    </message>
    <message>
        <source>This phrase</source>
        <translation>diese Wörter</translation>
    </message>
    <message>
        <source>Terms in proximity</source>
        <translation>ähnliche Ausdrücke</translation>
    </message>
    <message>
        <source>File name matching</source>
        <translation>passende Dateinamen</translation>
    </message>
    <message>
        <source>Select the type of query that will be performed with the words</source>
        <translation>Wählen Sie die Suchart aus, mit der nach den Wörtern gesucht wird</translation>
    </message>
    <message>
        <source>Number of additional words that may be interspersed with the chosen ones</source>
        <translation>Anzahl der Wörter, die sich zwischen den angegebenen befinden dürfen</translation>
    </message>
</context>
<context>
    <name>SortForm</name>
    <message>
        <source>Sort Criteria</source>
        <translation type="obsolete">Critères de tri</translation>
    </message>
    <message>
        <source>Sort the</source>
        <translation type="obsolete">Trier les</translation>
    </message>
    <message>
        <source>most relevant results by:</source>
        <translation type="obsolete">résultats les plus pertinents en fonction de:</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="obsolete">Décroissant</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="obsolete">Réinitialiser</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Schließen</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Mime type</source>
        <translation>Mime Type</translation>
    </message>
</context>
<context>
    <name>SortFormBase</name>
    <message>
        <source>Sort Criteria</source>
        <translation>Sortierkriterium</translation>
    </message>
    <message>
        <source>Sort the</source>
        <translation>Zeige die</translation>
    </message>
    <message>
        <source>most relevant results by:</source>
        <translation>relevantesten Ergebnisse sortiert nach:</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation>Absteigend</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="obsolete">Réinitialiser</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Übernehmen</translation>
    </message>
</context>
<context>
    <name>SpellBase</name>
    <message>
        <source>Term Explorer</source>
        <translation>Ausdruck Explorer</translation>
    </message>
    <message>
        <source>Enter word to expand</source>
        <translation type="obsolete">Entrer le mot à dériver</translation>
    </message>
    <message>
        <source>&amp;Expand </source>
        <translation>&amp;Vervollständigen</translation>
    </message>
    <message>
        <source>Alt+E</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+S</translation>
    </message>
    <message>
        <source>Term</source>
        <translation>Ausdruck</translation>
    </message>
    <message>
        <source>Count</source>
        <translation>Anzahl</translation>
    </message>
</context>
<context>
    <name>SpellW</name>
    <message>
        <source>Wildcards</source>
        <translation>Wildcards</translation>
    </message>
    <message>
        <source>Regexp</source>
        <translation>Regulärer Ausdruck</translation>
    </message>
    <message>
        <source>Spelling/Phonetic</source>
        <translation>Ortographie/Phonetik</translation>
    </message>
    <message>
        <source>Aspell init failed. Aspell not installed?</source>
        <translation>Fehler bei der Initialisierung von Aspell. Ist Aspell nicht installiert?</translation>
    </message>
    <message>
        <source>Aspell expansion error. </source>
        <translation>Aspell Vervollständigungsfehler.</translation>
    </message>
    <message>
        <source>No spelling expansion found</source>
        <translation type="obsolete">Pas de dérivés trouvés</translation>
    </message>
    <message>
        <source>Stem expansion</source>
        <translation>Wortstamm Erweiterung</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>Fehler beim Holen der Wortstammsprachen</translation>
    </message>
    <message>
        <source>No expansion found</source>
        <translation>Keine Erweiterung gefunden</translation>
    </message>
</context>
<context>
    <name>UIPrefsDialog</name>
    <message>
        <source>User interface</source>
        <translation type="obsolete">Interface utilisateur</translation>
    </message>
    <message>
        <source>Number of entries in a result page</source>
        <translation type="obsolete">Nombre de résultats par page</translation>
    </message>
    <message>
        <source>Result list font</source>
        <translation type="obsolete">Fonte pour la liste de résultats</translation>
    </message>
    <message>
        <source>Helvetica-10</source>
        <translation type="obsolete">Helvetica-10</translation>
    </message>
    <message>
        <source>Opens a dialog to select the result list font</source>
        <translation type="obsolete">Ouvre une fenetre permettant de changer la fonte</translation>
    </message>
    <message>
        <source>Show document type icons in result list</source>
        <translation type="obsolete">Afficher les icones dans la liste de résultats</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="obsolete">Réinitialiser</translation>
    </message>
    <message>
        <source>Resets the result list font to the system default</source>
        <translation type="obsolete">Réinitialiser la fonte à la valeur par défaut</translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation type="obsolete">Paramètres pour la recherche</translation>
    </message>
    <message>
        <source>Stemming language</source>
        <translation type="obsolete">Langue pour l&apos;expansion des termes</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation type="obsolete">Appliquer les modifications</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annuler</translation>
    </message>
    <message>
        <source>Discard changes</source>
        <translation type="obsolete">Abandonner les modifications</translation>
    </message>
    <message>
        <source>HTML help browser</source>
        <translation type="obsolete">Outil de consultation de l&apos;aide HTML</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation type="obsolete">Selectionner un fichier</translation>
    </message>
    <message>
        <source>Dynamically build abstracts</source>
        <translation type="obsolete">Construire dynamiquement les résumés</translation>
    </message>
    <message>
        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
May be slow for big documents.</source>
        <translation type="obsolete">Décide si des résumés seront construits à partir du contexte des termes de recherche. 
Peut ralentir l&apos;affichage si les documents sont gros.</translation>
    </message>
    <message>
        <source>Replace abstracts from documents</source>
        <translation type="obsolete">Remplacer les résumés existant dans les documents</translation>
    </message>
    <message>
        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
        <translation type="obsolete">Est-ce qu&apos;un résumé doit etre synthétisé meme dans le cas ou le document original en avait un?</translation>
    </message>
    <message>
        <source>Auto-start simple search on whitespace entry</source>
        <translation type="obsolete">Démarrage automatique de la recherche sur entrée d&apos;un espace</translation>
    </message>
    <message>
        <source>Extra Databases</source>
        <translation type="obsolete">Index extérieurs</translation>
    </message>
    <message>
        <source>Add database</source>
        <translation type="obsolete">Ajouter un index</translation>
    </message>
    <message>
        <source>Select the xapiandb directory for the  database you want to add, then click Add Database</source>
        <translation type="obsolete">Sélectionner le répertoire xapiandb pour l&apos;index(sp)(sp) que vous voulez ajouter, puis cliquer Ajouter Index</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="obsolete">Durchsuchen</translation>
    </message>
    <message>
        <source>All extra databases</source>
        <translation type="obsolete">Tous les index extérieurs</translation>
    </message>
    <message>
        <source>All known extra databases</source>
        <translation type="obsolete">Tous les index extérieurs connus</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation type="obsolete">Tout ----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation type="obsolete">Sel -----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation type="obsolete">&lt;----- Sel</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation type="obsolete">&lt;----- Tout</translation>
    </message>
    <message>
        <source>Active extra databases</source>
        <translation type="obsolete">Index extérieurs actifs</translation>
    </message>
    <message>
        <source>Extra databases that will be searched in addition to the main one</source>
        <translation type="obsolete">Index extérieurs utilisés</translation>
    </message>
    <message>
        <source>The selected directory does not appear to be a Xapian database</source>
        <translation type="obsolete">Le répertoire sélectionné ne semble pas être un index Xapian</translation>
    </message>
    <message>
        <source>This is the main/local database!</source>
        <translation type="obsolete">C&apos;est l&apos;index principal!</translation>
    </message>
    <message>
        <source>The selected directory is already in the database list</source>
        <translation type="obsolete">Le répertoire sélectionné existe déjà dans la liste</translation>
    </message>
    <message>
        <source>Select directory holding xapian database (ie: /home/someone/.recoll/xapiandb)</source>
        <translation type="obsolete">Sélectionner un répertoire contenant un index Xapian (ex: /home/someone/.recoll/xapiandb)</translation>
    </message>
    <message>
        <source>(no stemming)</source>
        <translation type="obsolete">(keine Wortstammerweiterung)</translation>
    </message>
    <message>
        <source>The selected directory does not appear to be a Xapian index</source>
        <translation>Das ausgewählte Verzeichnis scheint kein Xapian Index zu sein</translation>
    </message>
    <message>
        <source>This is the main/local index!</source>
        <translation>Das ist der Hauptindex!</translation>
    </message>
    <message>
        <source>The selected directory is already in the index list</source>
        <translation>Das ausgewählte Verzeichnis ist bereits Teil der Indexliste</translation>
    </message>
    <message>
        <source>Select xapian index directory (ie: /home/buddy/.recoll/xapiandb)</source>
        <translation>Wählen Sie das Xapian Indexverzeichnis (Z.B.: /home/benutzer/.recoll/xapiandb)</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>Fehler beim Holen der Wortstammsprachen</translation>
    </message>
</context>
<context>
    <name>UIPrefsDialogBase</name>
    <message>
        <source>MyDialog</source>
        <translation type="obsolete">MonDialogue</translation>
    </message>
    <message>
        <source>User interface</source>
        <translation>Benutzeroberfläche</translation>
    </message>
    <message>
        <source>Number of entries in a result page</source>
        <translation>Anzahl der Ergebnisse pro Seite</translation>
    </message>
    <message>
        <source>Result list font</source>
        <translation>Schriftart für Ergebnisliste</translation>
    </message>
    <message>
        <source>Helvetica-10</source>
        <translation>Helvetica-10</translation>
    </message>
    <message>
        <source>Opens a dialog to select the result list font</source>
        <translation>Öffnet einen Dialog zur Auswahl der Schriftart für die Ergebnisliste</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reset</translation>
    </message>
    <message>
        <source>Resets the result list font to the system default</source>
        <translation>Setzt die Schriftart für die Ergebnisliste zurück auf den Standardwert</translation>
    </message>
    <message>
        <source>HTML help browser</source>
        <translation type="obsolete">Browser für HTML-Hilfe</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation type="obsolete">Auswählen</translation>
    </message>
    <message>
        <source>Show document type icons in result list.</source>
        <translation type="obsolete">Zeige Dokumenttypicons in der Ergebnisliste.</translation>
    </message>
    <message>
        <source>Auto-start simple search on whitespace entry.</source>
        <translation>Automatisch eine einfache Suche starten, wenn ein Worttrenner im Sucheingabefeld eingegeben wird.</translation>
    </message>
    <message>
        <source>Start with advanced search dialog open.</source>
        <translation>Nach dem Start automatisch den Dialog für die erweiterte Suche öffnen.</translation>
    </message>
    <message>
        <source>Start with sort dialog open.</source>
        <translation>Nach dem Start automatisch den Sortierdialog öffnen.</translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation>Suchparameter</translation>
    </message>
    <message>
        <source>Stemming language</source>
        <translation>Stemming Sprache</translation>
    </message>
    <message>
        <source>Automatically add phrase to simple searchs</source>
        <translation type="obsolete">Générer automatiquement une phrase ajoutée aux critères de la recherche simple</translation>
    </message>
    <message>
        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)].</source>
        <translation type="obsolete">Une recherche de  [rolling stones] (2 termes) sera changée en [rolling or stones or (rolling phrase 2 stones)].</translation>
    </message>
    <message>
        <source>Dynamically build abstracts</source>
        <translation>Zusammenfassungen dynamisch erzeugen</translation>
    </message>
    <message>
        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
May be slow for big documents.</source>
        <translation>Festlegung ob Zusammenfassungen für Ergebnisse im Kontext der Suchparameter erzeugt werden (kann bei großen Dokumenten langsam sein).</translation>
    </message>
    <message>
        <source>Replace abstracts from documents</source>
        <translation>Ersetzen der Zusammenfassungen in den Dokumenten</translation>
    </message>
    <message>
        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
        <translation>Festlegung ob eine Zusammenfassung auch dann erzeugt wird, wenn das Dokument schon eine Zusammenfassung enthält</translation>
    </message>
    <message>
        <source>Synthetic abstract size (characters)</source>
        <translation>Länge der erzeugten Zusammenfassung (Zeichen)</translation>
    </message>
    <message>
        <source>Synthetic abstract context words</source>
        <translation>Anzahl der Kontextworte in der Zusammenfassung</translation>
    </message>
    <message>
        <source>External Indexes</source>
        <translation>externe Indizes</translation>
    </message>
    <message>
        <source>Add index</source>
        <translation>Index hinzufügen</translation>
    </message>
    <message>
        <source>Select the xapiandb directory for the index you want to add, then click Add Index</source>
        <translation>Wählen Sie das xapiandb-Verzeichnis des zuzufügenden Indizes und klicken Sie auf Index hinzufügen</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Auswahl</translation>
    </message>
    <message>
        <source>All indexes</source>
        <translation type="obsolete">Tous les index</translation>
    </message>
    <message>
        <source>Indexes currently not used</source>
        <translation type="obsolete">Index inactifs</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation type="obsolete">Tout ----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation type="obsolete">Sel -----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation type="obsolete">&lt;----- Sel</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation type="obsolete">&lt;----- Tout</translation>
    </message>
    <message>
        <source>Active indexes</source>
        <translation type="obsolete">Index actifs</translation>
    </message>
    <message>
        <source>Indexes that will be searched in addition to the main one</source>
        <translation type="obsolete">Index actifs en plus de l&apos;index principal</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation>Änderungen übernehmen</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>Discard changes</source>
        <translation>Änderungen verwerfen</translation>
    </message>
    <message>
        <source>Result paragraph&lt;br&gt;format string</source>
        <translation>Formatstring 
für Ergebnisse</translation>
    </message>
    <message>
        <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
        <translation type="obsolete">Definitions des Formats für die Absätze in der Ergebnisliste. Zur Konfiguration nutzen Sie QT HMTL-Formatierungen und printf ähnliche Ersetzungen:
%A Zusammenfassung
%D Datum
%K Schlüsselworte (wenn vorhanden)
%L Vorschau und Editierlinks 
%M Mime Type
%N Ergebnisnummer
 %R Relevanz in Prozent 
 %S Größeninformationen
 %T Titel
 %U URL
</translation>
    </message>
    <message>
        <source>Automatically add phrase to simple searches</source>
        <translation>Automatisches Zufügen von Sätzen zu einfachen Suchen</translation>
    </message>
    <message>
        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)]. 
This should give higher precedence to the results where the search terms appear exactly as entered.</source>
        <translation>Eine Suche nach [Jürgen Klinsmann] wird geändert nach [Jürgen OR Klinsmann OR (Jürgen PHRASE 2 Klinsmann)].
Dadurch sollten Ergebnisse, die exakte Übereinstimmungen der Suchworte enthalten, stärker gewichtet werden.</translation>
    </message>
    <message>
        <source>Choose external viewer applications</source>
        <translation type="obsolete">Festlegung der externen Programme zum Öffnen der Dokumente</translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="obsolete">Auswählen</translation>
    </message>
    <message>
        <source>User preferences</source>
        <translation>Benutzereinstellungen</translation>
    </message>
    <message>
        <source>Use desktop preferences to choose document editor.</source>
        <translation>Die Einstellung des Dokumenteneditors erfolgt in den Desktopvoreinstellungen.</translation>
    </message>
    <message>
        <source>External indexes</source>
        <translation>Externe Indizes</translation>
    </message>
    <message>
        <source>Toggle selected</source>
        <translation>Auswahl umkehren</translation>
    </message>
    <message>
        <source>Activate All</source>
        <translation>Alle Auswählen</translation>
    </message>
    <message>
        <source>Deactivate All</source>
        <translation>Alle Abwählen</translation>
    </message>
    <message>
        <source>Remove selected</source>
        <translation>Ausgewählte entfernen</translation>
    </message>
    <message>
        <source>Remove from list. This has no effect on the disk index.</source>
        <translation>Aus der Liste entfernen. Dies hat keinen Einfluss auf den gespeicherten Index.</translation>
    </message>
    <message>
        <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember sort activation state.</source>
        <translation>Speichern, ob Sortieren aktiviert ist.</translation>
    </message>
    <message>
        <source>Maximum text size highlighted for preview (megabytes)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Texts over this size will not be highlighted in preview (too slow).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Highlight color for query terms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prefer Html to plain text for preview.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If checked, results with the same content under different names will only be shown once.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide duplicate results.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose editor applications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewAction</name>
    <message>
        <source>Changing actions with differentcurrent values</source>
        <translation type="obsolete">Changing actions with different current values</translation>
    </message>
    <message>
        <source>Changing actions with different current values</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewActionBase</name>
    <message>
        <source>Form1</source>
        <translation type="obsolete">Form1</translation>
    </message>
    <message>
        <source>File type</source>
        <translation>Dateityp</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Aktion</translation>
    </message>
    <message>
        <source>Select one or several file types, then click Change Action to modify the program used to open them</source>
        <translation>Wählen Sie einen oder mehrere Dateitypen und klicken Sie auf &quot;Ändere Aktion&quot; um das verknüpfte Programm zum Öffnen anzupassen. </translation>
    </message>
    <message>
        <source>Change Action</source>
        <translation>Ändere Aktion</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Native Viewers</source>
        <translation>Anzeigeprogramme</translation>
    </message>
    <message>
        <source>Select one or several mime types then click &quot;Change Action&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>advsearch</name>
    <message>
        <source>Advanced search</source>
        <translation type="obsolete">Recherche avancée</translation>
    </message>
    <message>
        <source>Search For</source>
        <translation type="obsolete">Rechercher</translation>
    </message>
    <message>
        <source>All these words</source>
        <translation type="obsolete">Tous les mots</translation>
    </message>
    <message>
        <source>This exact phrase</source>
        <translation type="obsolete">Cette phrase exactement</translation>
    </message>
    <message>
        <source>Any of these words</source>
        <translation type="obsolete">N&apos;importe lequel de ces mots</translation>
    </message>
    <message>
        <source>None of these words</source>
        <translation type="obsolete">Aucun parmi ces mots</translation>
    </message>
    <message>
        <source>Restrict file types</source>
        <translation type="obsolete">Restraindre le type de fichier</translation>
    </message>
    <message>
        <source>Searched file types</source>
        <translation type="obsolete">Type de fichier recherché</translation>
    </message>
    <message>
        <source>Ignored file types</source>
        <translation type="obsolete">Types de fichier ignorés</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="obsolete">Durchsuchen</translation>
    </message>
    <message>
        <source>Restrict results to files in subtree:</source>
        <translation type="obsolete">Restreindre les résultats aux fichiers de l&apos;arborescence:</translation>
    </message>
    <message>
        <source>Start Search</source>
        <translation type="obsolete">Lancer la recherche</translation>
    </message>
    <message>
        <source>Dismiss</source>
        <translation type="obsolete">Annuler</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation type="obsolete">Tout ----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation type="obsolete">Sel -----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation type="obsolete">&lt;----- Sel</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation type="obsolete">&lt;----- Tout</translation>
    </message>
    <message>
        <source>Search for files&lt;br&gt;having all of:</source>
        <translation type="obsolete">Rechercher les fichiers&lt;br&gt;vérifiant:</translation>
    </message>
    <message>
        <source>All non blank fields will be combined with AND conjunctions</source>
        <translation type="obsolete">Tous les champs renseignés seront combinés par des ET</translation>
    </message>
    <message>
        <source>File name matching</source>
        <translation type="obsolete">Modèle de nom de fichier</translation>
    </message>
    <message>
        <source>Cannot execute pure negative query. Please enter common terms in the &apos;any words&apos; field</source>
        <translation type="obsolete">Impossible d&apos;éxécuter une requête purement négative. Essayez d&apos;entrer des termes courants dans un champ &apos;ou&apos;</translation>
    </message>
</context>
<context>
    <name>confgui::ConfIndexW</name>
    <message>
        <source>Can&apos;t write configuration file</source>
        <translation>Kann Konfigurationsdatei nicht schreiben</translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamFNW</name>
    <message>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamSLW</name>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
</context>
<context>
    <name>confgui::ConfSubPanelW</name>
    <message>
        <source>Global</source>
        <translation>Global</translation>
    </message>
    <message>
        <source>Max. compressed file size (KB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This value sets a threshold beyond which compressedfiles will not be processed. Set to -1 for no limit, to 0 for no decompression ever.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfTopPanelW</name>
    <message>
        <source>Top directories</source>
        <translation>Start-Verzeichnisse</translation>
    </message>
    <message>
        <source>The list of directories where recursive indexing starts. Default: your home.</source>
        <translation>Die Liste der Verzeichnisse in der die rekursive Indizierung startet. Standard: Home-Verzeichnis.</translation>
    </message>
    <message>
        <source>Skipped paths</source>
        <translation>Ausgelassene Pfade</translation>
    </message>
    <message>
        <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/me/tmp*&apos;, not &apos;/usr/home/me/tmp*&apos;)</source>
        <translation>Die Namen der Verzeichnisse, die nicht indiziert werden.&lt;br&gt;Kann Wildcards enthalten. Muss den Pfaden entsprechen, die der Indexer sieht (z.B. wenn &apos;/home/me&apos; in den topdirs steht und &apos;/home&apos; eigentlich ein link zu &apos;/usr/home&apos; ist, dann wäre ein korrekter skippedPath Eintrag &apos;/home/me/tmp*&apos; und nicht &apos;/usr/home/me/tmp*&apos;)</translation>
    </message>
    <message>
        <source>Stemming languages</source>
        <translation>Wortstammerweiterungssprachen</translation>
    </message>
    <message>
        <source>The languages for which stemming expansion&lt;br&gt;dictionaries will be built.</source>
        <translation>Die Sprachen für die Worstammerweiterungs-&lt;br&gt;verzeichnisse erstellt werden.</translation>
    </message>
    <message>
        <source>Log file name</source>
        <translation>Log Datei</translation>
    </message>
    <message>
        <source>The file where the messages will be written.&lt;br&gt;Use &apos;stderr&apos; for terminal output</source>
        <translation>Die Datei in die Ausgaben geschrieben werden.&lt;br&gt;Für Ausgaben auf demTerminal &apos;stderr&apos; benutzen</translation>
    </message>
    <message>
        <source>Log verbosity level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This value adjusts the amount of messages,&lt;br&gt;from only errors to a lot of debugging data.</source>
        <translation>Dieser Wert stellt den Umfang der Ausgaben ein.&lt;br&gt;Nur Fehler bis zu einer Menge von Debug Ausgaben.</translation>
    </message>
    <message>
        <source>Index flush megabytes interval</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This value adjust the amount of data which is indexed between flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max disk occupation (%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the percentage of disk occupation where indexing will fail and stop (to avoid filling up your disk).&lt;br&gt;0 means no limit (this is the default).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No aspell usage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aspell language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The language for the aspell dictionary. This should look like &apos;en&apos; or &apos;fr&apos; ...&lt;br&gt;If this value is not set, the NLS environment will be used to compute it, which usually works.To get an idea of what is installed on your system, type &apos;aspell config&apos; and look for .dat files inside the &apos;data-dir&apos; directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database directory name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name for a directory where to store the index&lt;br&gt;A non-absolute path is taken relative to the  configuration directory. The default is &apos;xapiandb&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system&apos;s &apos;file&apos; command</source>
        <translation>&apos;file&apos; Komando benutzen</translation>
    </message>
    <message>
        <source>Use the system&apos;s &apos;file&apos; command if internal&lt;br&gt;mime type identification fails.</source>
        <translation>Benutze das &apos;file&apos; Kommando wenn die interne&lt;br&gt;mime Typ Erkennung fehlschlägt.</translation>
    </message>
    <message>
        <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful if aspell is absent or does not work. </source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
